@@ -1,4 +1,4 @@
-from files import reader, tokens, nopen
+from files import reader, tokens, nopen, header
 import sys
 
 try:
