@@ -5,6 +5,7 @@ import sys
 import gzip
 import bz2
 from itertools import izip
+import urllib
 
 
 def nopen(f, mode="rb"):
@@ -24,9 +25,11 @@ def nopen(f, mode="rb"):
     if not isinstance(f, basestring):
         return f
     return {"r": sys.stdin, "w": sys.stdout}[mode[0]] if f == "-" \
-         else gzip.open(f, mode) if f.endswith(".gz") \
-         else bz2.BZ2File(f, mode) if f.endswith((".bz", ".bz2")) \
-         else open(f, mode)
+         else gzip.open(f, mode) if f.endswith((".gz", ".Z", ".z")) \
+         else bz2.BZ2File(f, mode) if f.endswith((".bz", ".bz2", ".bzip2")) \
+         else urllib.urlopen(f) if f.startswith(("http://", "https://",
+             "ftp://")) \
+        else open(f, mode)
 
 
 def tokens(line, sep="\t"):
